==> lxqt-l10n-0.11.2.tar.xz: lxqt-l10n-0.11.2/lximage-qt/lximage-qt_sv.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sv">
<context>
    <name>../data/lxinput.desktop.in.h:1</name>
    <message>
        <source>Keyboard and Mouse</source>
        <translation type="obsolete">Tangentbord och mus</translation>
    </message>
</context>
<context>
    <name>../data/lxinput.desktop.in.h:2</name>
    <message>
        <source>Configure keyboard, mouse, and other input devices</source>
        <translation type="obsolete">Inställningar för tangentbord, mus och andra inmatningsenheter</translation>
    </message>
</context>
<context>
    <name>../data/lxinput.ui.h:1</name>
    <message>
        <source>Input Device Preferences</source>
        <translation type="obsolete">Egenskaper för inmatningsenhet</translation>
    </message>
</context>
<context>
    <name>../data/lxinput.ui.h:10</name>
    <message>
        <source>Mouse</source>
        <translation type="obsolete">Mus</translation>
    </message>
</context>
<context>
    <name>../data/lxinput.ui.h:11</name>
    <message>
        <source>Delay before each key starts repeating</source>
        <translation type="obsolete">Tid innan varje tangent repeteras</translation>
    </message>
</context>
<context>
    <name>../data/lxinput.ui.h:12</name>
    <message>
        <source>Repeat delay:</source>
        <translation type="obsolete">Tid innan upprepning:</translation>
    </message>
</context>
<context>
    <name>../data/lxinput.ui.h:13</name>
    <message>
        <source>Interval between each key repeat</source>
        <translation type="obsolete">Intervall mellan upprening av tangenter</translation>
    </message>
</context>
<context>
    <name>../data/lxinput.ui.h:14</name>
    <message>
        <source>Long</source>
        <translation type="obsolete">Lång</translation>
    </message>
</context>
<context>
    <name>../data/lxinput.ui.h:15</name>
    <message>
        <source>Short</source>
        <translation type="obsolete">Kort</translation>
    </message>
</context>
<context>
    <name>../data/lxinput.ui.h:16</name>
    <message>
        <source>Repeat interval:</source>
        <translation type="obsolete">Tid mellan upprepningar:</translation>
    </message>
</context>
<context>
    <name>../data/lxinput.ui.h:17</name>
    <message>
        <source>Type in the following box to test your keyboard settings</source>
        <translation type="obsolete">För att pröva dina inställningar kan du skriva i följande ruta</translation>
    </message>
</context>
<context>
    <name>../data/lxinput.ui.h:18</name>
    <message>
        <source>&lt;b&gt;Character Repeat&lt;/b&gt;</source>
        <translation type="obsolete">&lt;b&gt;Teckenupprepning&lt;/b&gt;</translation>
    </message>
</context>
<context>
    <name>../data/lxinput.ui.h:19</name>
    <message>
        <source>Beep when there is an error of keyboard input</source>
        <translation type="obsolete">Avge ett pip när ett fel uppstår vid tangentbordsinmatning</translation>
    </message>
</context>
<context>
    <name>../data/lxinput.ui.h:2</name>
    <message>
        <source>Sensitivity:</source>
        <translation type="obsolete">Känslighet:</translation>
    </message>
</context>
<context>
    <name>../data/lxinput.ui.h:20</name>
    <message>
        <source>&lt;b&gt;Keyboard layout&lt;/b&gt;</source>
        <translation type="obsolete">&lt;b&gt;Tangentbordsupplägg&lt;/b&gt;</translation>
    </message>
</context>
<context>
    <name>../data/lxinput.ui.h:21</name>
    <message>
        <source>Keyboard</source>
        <translation type="obsolete">Tangentbord</translation>
    </message>
</context>
<context>
    <name>../data/lxinput.ui.h:22</name>
    <message>
        <source>Touch Pad</source>
        <translation type="obsolete">Pekplatta</translation>
    </message>
</context>
<context>
    <name>../data/lxinput.ui.h:3</name>
    <message>
        <source>High</source>
        <translation type="obsolete">Hög</translation>
    </message>
</context>
<context>
    <name>../data/lxinput.ui.h:4</name>
    <message>
        <source>Low</source>
        <translation type="obsolete">Låg</translation>
    </message>
</context>
<context>
    <name>../data/lxinput.ui.h:5</name>
    <message>
        <source>Fast</source>
        <translation type="obsolete">Snabb</translation>
    </message>
</context>
<context>
    <name>../data/lxinput.ui.h:6</name>
    <message>
        <source>Slow</source>
        <translation type="obsolete">Långsam</translation>
    </message>
</context>
<context>
    <name>../data/lxinput.ui.h:7</name>
    <message>
        <source>Acceleration:</source>
        <translation type="obsolete">Acceleration:</translation>
    </message>
</context>
<context>
    <name>../data/lxinput.ui.h:8</name>
    <message>
        <source>&lt;b&gt;Motion&lt;/b&gt;</source>
        <translation type="obsolete">&lt;b&gt;Förflyttning&lt;/b&gt;</translation>
    </message>
</context>
<context>
    <name>../data/lxinput.ui.h:9</name>
    <message>
        <source>Left handed (Swap left and right mouse buttons)</source>
        <translation type="obsolete">Vänsterhänt (byt funktioner för vänster och höger musknapp)</translation>
    </message>
</context>
<context>
    <name>LxImage::Application</name>
    <message>
        <source>Take a screenshot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>[FILE1, FILE2,...]</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LxImage::MainWindow</name>
    <message>
        <source>About</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>LXImage - a simple and fast image viewer

Copyright (C) 2013
LXDE Project: http://lxde.org/

Authors:
Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Image files (%1)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Thumbnails</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>[*]%1 (Loading...) - Image Viewer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>[*]%1 (Failed to Load) - Image Viewer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>[*]%1 (%2x%3) - Image Viewer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>[*]Image Viewer</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Image Viewer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Open File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+S</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save &amp;As</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+A</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+W</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Zoom &amp;In</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl++</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Zoom &amp;Out</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Copy to Clipboard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Next File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Previous File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Original Size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Fit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Rotate Clockwise</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rotate &amp;Counterclockwise</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>P&amp;references</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Print</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>First File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Home</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Last File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>End</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;New Window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+N</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Flip &amp;Horizontally</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Capture Screenshot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>F&amp;ull Screen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>F11</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Flip &amp;Vertically</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Paste from Clipboard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Slide Show</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Del</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Go</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Toolbar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PgDown</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PgUp</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+P</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show Thumbnails</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>File Properties</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <source>Preferences</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Icon theme:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Normal background color:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fullscreen background color:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Slide show interval (seconds):</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>General</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ScreenshotDialog</name>
    <message>
        <source>Screenshot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Take a screenshot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Region</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Whole screen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Current window only</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Include mouse cursor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source> seconds</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delay:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Include window title and frame</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> lxqt-l10n_0.12.0.orig.tar.xz: lxqt-l10n-0.12.0/lximage-qt/lximage-qt_sv.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sv">
<context>
    <name>../data/lxinput.desktop.in.h:1</name>
    <message>
        <source>Keyboard and Mouse</source>
        <translation type="obsolete">Tangentbord och mus</translation>
    </message>
</context>
<context>
    <name>../data/lxinput.desktop.in.h:2</name>
    <message>
        <source>Configure keyboard, mouse, and other input devices</source>
        <translation type="obsolete">Inställningar för tangentbord, mus och andra inmatningsenheter</translation>
    </message>
</context>
<context>
    <name>../data/lxinput.ui.h:1</name>
    <message>
        <source>Input Device Preferences</source>
        <translation type="obsolete">Egenskaper för inmatningsenhet</translation>
    </message>
</context>
<context>
    <name>../data/lxinput.ui.h:10</name>
    <message>
        <source>Mouse</source>
        <translation type="obsolete">Mus</translation>
    </message>
</context>
<context>
    <name>../data/lxinput.ui.h:11</name>
    <message>
        <source>Delay before each key starts repeating</source>
        <translation type="obsolete">Tid innan varje tangent repeteras</translation>
    </message>
</context>
<context>
    <name>../data/lxinput.ui.h:12</name>
    <message>
        <source>Repeat delay:</source>
        <translation type="obsolete">Tid innan upprepning:</translation>
    </message>
</context>
<context>
    <name>../data/lxinput.ui.h:13</name>
    <message>
        <source>Interval between each key repeat</source>
        <translation type="obsolete">Intervall mellan upprening av tangenter</translation>
    </message>
</context>
<context>
    <name>../data/lxinput.ui.h:14</name>
    <message>
        <source>Long</source>
        <translation type="obsolete">Lång</translation>
    </message>
</context>
<context>
    <name>../data/lxinput.ui.h:15</name>
    <message>
        <source>Short</source>
        <translation type="obsolete">Kort</translation>
    </message>
</context>
<context>
    <name>../data/lxinput.ui.h:16</name>
    <message>
        <source>Repeat interval:</source>
        <translation type="obsolete">Tid mellan upprepningar:</translation>
    </message>
</context>
<context>
    <name>../data/lxinput.ui.h:17</name>
    <message>
        <source>Type in the following box to test your keyboard settings</source>
        <translation type="obsolete">För att pröva dina inställningar kan du skriva i följande ruta</translation>
    </message>
</context>
<context>
    <name>../data/lxinput.ui.h:18</name>
    <message>
        <source>&lt;b&gt;Character Repeat&lt;/b&gt;</source>
        <translation type="obsolete">&lt;b&gt;Teckenupprepning&lt;/b&gt;</translation>
    </message>
</context>
<context>
    <name>../data/lxinput.ui.h:19</name>
    <message>
        <source>Beep when there is an error of keyboard input</source>
        <translation type="obsolete">Avge ett pip när ett fel uppstår vid tangentbordsinmatning</translation>
    </message>
</context>
<context>
    <name>../data/lxinput.ui.h:2</name>
    <message>
        <source>Sensitivity:</source>
        <translation type="obsolete">Känslighet:</translation>
    </message>
</context>
<context>
    <name>../data/lxinput.ui.h:20</name>
    <message>
        <source>&lt;b&gt;Keyboard layout&lt;/b&gt;</source>
        <translation type="obsolete">&lt;b&gt;Tangentbordsupplägg&lt;/b&gt;</translation>
    </message>
</context>
<context>
    <name>../data/lxinput.ui.h:21</name>
    <message>
        <source>Keyboard</source>
        <translation type="obsolete">Tangentbord</translation>
    </message>
</context>
<context>
    <name>../data/lxinput.ui.h:22</name>
    <message>
        <source>Touch Pad</source>
        <translation type="obsolete">Pekplatta</translation>
    </message>
</context>
<context>
    <name>../data/lxinput.ui.h:3</name>
    <message>
        <source>High</source>
        <translation type="obsolete">Hög</translation>
    </message>
</context>
<context>
    <name>../data/lxinput.ui.h:4</name>
    <message>
        <source>Low</source>
        <translation type="obsolete">Låg</translation>
    </message>
</context>
<context>
    <name>../data/lxinput.ui.h:5</name>
    <message>
        <source>Fast</source>
        <translation type="obsolete">Snabb</translation>
    </message>
</context>
<context>
    <name>../data/lxinput.ui.h:6</name>
    <message>
        <source>Slow</source>
        <translation type="obsolete">Långsam</translation>
    </message>
</context>
<context>
    <name>../data/lxinput.ui.h:7</name>
    <message>
        <source>Acceleration:</source>
        <translation type="obsolete">Acceleration:</translation>
    </message>
</context>
<context>
    <name>../data/lxinput.ui.h:8</name>
    <message>
        <source>&lt;b&gt;Motion&lt;/b&gt;</source>
        <translation type="obsolete">&lt;b&gt;Förflyttning&lt;/b&gt;</translation>
    </message>
</context>
<context>
    <name>../data/lxinput.ui.h:9</name>
    <message>
        <source>Left handed (Swap left and right mouse buttons)</source>
        <translation type="obsolete">Vänsterhänt (byt funktioner för vänster och höger musknapp)</translation>
    </message>
</context>
<context>
    <name>LxImage::Application</name>
    <message>
        <source>Take a screenshot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>[FILE1, FILE2,...]</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LxImage::MainWindow</name>
    <message>
        <source>About</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>LXImage - a simple and fast image viewer

Copyright (C) 2013
LXDE Project: http://lxde.org/

Authors:
Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Image files (%1)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Thumbnails</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>[*]%1 (Loading...) - Image Viewer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>[*]%1 (Failed to Load) - Image Viewer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>[*]%1 (%2x%3) - Image Viewer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>[*]Image Viewer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open directory</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Image Viewer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Open File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+S</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save &amp;As</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+A</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+W</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Zoom &amp;In</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Zoom &amp;Out</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Copy to Clipboard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Next File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Previous File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Original Size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Fit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Rotate Clockwise</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rotate &amp;Counterclockwise</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>P&amp;references</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Print</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>First File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Home</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Last File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>End</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;New Window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+N</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Flip &amp;Horizontally</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Capture Screenshot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>F&amp;ull Screen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>F11</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Flip &amp;Vertically</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Paste from Clipboard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Slide Show</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Del</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Go</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Toolbar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PgDown</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PgUp</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+P</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show Thumbnails</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>File Properties</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+=</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+0</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open &amp;Directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+D</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <source>Preferences</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Icon theme:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Normal background color:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fullscreen background color:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Slide show interval (seconds):</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>General</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ScreenshotDialog</name>
    <message>
        <source>Screenshot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Take a screenshot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Region</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Whole screen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Current window only</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Include mouse cursor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source> seconds</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delay:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Include window title and frame</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Capture an area of the screen</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
